@@ -285,8 +285,8 @@ class Updater:
     def update(
         self,
         device: TrussedBase,
-        image: Optional[str],
-        update_version: Optional[str],
+        image: Optional[str] = None,
+        update_version: Optional[str] = None,
         ignore_pynitrokey_version: bool = False,
     ) -> Tuple[Version, Status]:
         model = device.model
@@ -547,7 +547,8 @@ class Updater:
             raise self.ui.error(str(e))
 
         txt = _get_extra_information(migrations)
-        self.ui.confirm_extra_information(txt)
+        if len(txt) > 0:
+            self.ui.confirm_extra_information(txt)
 
         if _Migration.IFS_MIGRATION_V2 in migrations:
             if status and status.ifs_blocks is not None and status.ifs_blocks < 5:
